<?php

namespace Drupal\Tests\reverse_proxy_header\Kernel;

/**
 * Test class for ReverseProxyHeaderClientIpRestore service.
 *
 * @group reverse_proxy_header
 */
class ClientIpRestoreTest extends ReverseProxyHeaderTestBase {

  /**
   * Test ReverseProxyHeaderClientIpRestore service using valid IP addresses.
   *
   * @param string $header_name
   *   The header name.
   * @param string $valid_ip
   *   The valid client IP address.
   * @param string $invalid_ip
   *   The invalid client IP address.
   *
   * @dataProvider providerClientIpsHeaders
   */
  public function testValidIps($header_name, $valid_ip, $invalid_ip) {
    $request = $this->reverseProxyHeaderRequest($header_name, $valid_ip);
    $this->assertEquals($request->getClientIp(), $valid_ip);
  }

  /**
   * Test ReverseProxyHeaderClientIpRestore service using invalid IP addresses.
   *
   * @param string $header_name
   *   The header name.
   * @param string $valid_ip
   *   The valid client IP address.
   * @param string $invalid_ip
   *   The invalid client IP address.
   *
   * @dataProvider providerClientIpsHeaders
   */
  public function testInvalidIps($header_name, $valid_ip, $invalid_ip) {
    $this->reverseProxyHeaderRequest($header_name, $invalid_ip);
    $this->assertInvalidIpNoticeExist($invalid_ip, $header_name);
  }

  /**
   * Provider for testing ClientIpRestoreTest.
   *
   * @return array
   *   Test Data to simulate incoming IP address.
   */
  public function providerClientIpsHeaders() {
    return [
      [
        // It should work well with default headers as well.
        'HEADER_X_FORWARDED_FOR',
        '127.0.0.1',
        '',
      ],
      [
        'CUSTOM_HEADER_2',
        '10.0.10.10',
        '',
      ],
      [
        'HEADER_CUSTOM_HEADER_3',
        '1.1.1.1',
        '444.555.666.777',
      ],
      [
        'HEADER_X_CUSTOM_HEADER_4',
        '8.8.8.8',
        'this_is_a_text_not_ip',
      ],
    ];
  }

}
